==> moodle-1.5-pgsql.tgz: moodle/lang/sk/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.6 development (2005052400)


$string['asset'] = 'Hodnota';
$string['attr_error'] = 'Nesprvna hodnota atribtu ($a->attr) v tagu $a->tag.';
$string['autocontinue'] = 'Automatick pokraovanie';
$string['badmanifest'] = 'Chyby v manifeste: vi zznamy o chybch';
$string['browse'] = 'Prechdza';
$string['browsed'] = 'Prechdzan';
$string['browsemode'] = 'Reim prechdzania';
$string['chooseapacket'] = 'Vybra alebo aktualizova balk SCORM';
$string['completed'] = 'Dokonen';
$string['coursepacket'] = 'Balk kurzu';
$string['coursestruct'] = 'truktra kurzu';
$string['datadir'] = 'Chyba v systme sborov: Ned sa vytvori adresr s dajmi kurzu';
$string['details'] = 'Detaily priechodu SCO ';
$string['display'] = 'Zobraz';
$string['domxml'] = 'Extern kninica DOMXML';
$string['enablebrowse'] = 'Zapn nhad';
$string['entercourse'] = 'Vstpi do SCORM kurzu';
$string['errorlogs'] = 'Zznamy o chybch';
$string['exit'] = 'Opusti SCORM kurz';
$string['expcoll'] = 'Rozbali/Zabali';
$string['failed'] = 'Zlyhalo';
$string['firstaccess'] = 'Prv prstup';
$string['found'] = 'Manifest bol njden';
$string['frameheight'] = 'Tto hodnota nastav vchodziu hodnotu vky rmu SCO';
$string['framewidth'] = 'Tto hodnota nastav vchodziu hodnotu rky rmu SCO';
$string['gradeaverage'] = 'Priemern poet bodov';
$string['gradehighest'] = 'Najvy poet bodov';
$string['grademethod'] = 'Metda bodovania';
$string['gradescoes'] = 'Scoes situcia';
$string['gradesum'] = 'Celkov poet bodov';
$string['guestsno'] = 'Hosovskm uvateom nie je povolen zobrazenie SCORM kurzov';
$string['height'] = 'Vka';
$string['incomplete'] = 'Nedokonen';
$string['lastaccess'] = 'Posledn prstup';
$string['missing_attribute'] = 'Chba atribt $a->attr v tagu $a->tag';
$string['missing_tag'] = 'Chba tag $a->tag';
$string['mode'] = 'Reim';
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMy';
$string['next'] = 'Pokraova';
$string['no_attributes'] = 'Tag $a->tag mus ma atribty';
$string['no_children'] = 'Tag $a->tag mus ma deti';
$string['noactivity'] = 'iadna sprva';
$string['nomanifest'] = 'Manifest nebol njden';
$string['noreports'] = 'iadna sprva na zobrazenie';
$string['normal'] = 'Normlny';
$string['not_corr_type'] = 'Neslad typov v tagu $a->tag';
$string['notattempted'] = 'Bez pokusov';
$string['organization'] = 'Organizcia';
$string['organizations'] = 'Organizcie';
$string['packagedir'] = 'Chyba v systme sborov: Ned sa vytvori adresr s balkom';
$string['passed'] = 'Preiel';
$string['php5'] = 'PHP 5 (DOMXML rodn kninica)';
$string['popup'] = 'Otvori sasn SCO v novom okne';
$string['position_error'] = 'Tag $a->tag neme by dieaom tagu $a->parent';
$string['prev'] = 'Predchdzajci';
$string['regular'] = 'Regulrny manifest';
$string['report'] = 'Sprva';
$string['review'] = 'Znovu prehliadnu';
$string['scoes'] = 'Scoes';
$string['score'] = 'Skre';
$string['syntax'] = 'Chyba v syntaxi';
$string['tag_error'] = 'Neznmy tag ($a->tag) s tmto obsahom: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag m prli mnoho atribtov';
$string['too_many_children'] = 'Tag $a->tag m prli mnoho det';
$string['totaltime'] = 'as';
$string['trackingloose'] = 'UPOZORNENIE: daje o priechode tmto SCORM balkom bud straten!';
$string['validateascorm'] = 'Overi SCORM balk';
$string['validation'] = 'Vsledok overovania';
$string['validationtype'] = 'Tto vlastnos nastavuje kninicu DOMXML, ktor bude pouit pri overovan manifestu SCORM. Ak neviete, o zvoli, nechajte tu vybrat odpove.';
$string['versionwarning'] = 'Verzia manifestu je staria ako 1.3, upozornenie na tagu $a->tag';
$string['viewallreports'] = 'Zobrazi sprvy pre $a pokusov';
$string['width'] = 'rka';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/sk/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.6 development (2005052400)


$string['asset'] = 'Hodnota';
$string['attr_error'] = 'Nesprvna hodnota atribtu ($a->attr) v tagu $a->tag.';
$string['autocontinue'] = 'Automatick pokraovanie';
$string['badmanifest'] = 'Chyby v manifeste: vi zznamy o chybch';
$string['browse'] = 'Prechdza';
$string['browsed'] = 'Prechdzan';
$string['browsemode'] = 'Reim prechdzania';
$string['chooseapacket'] = 'Vybra alebo aktualizova balk SCORM';
$string['completed'] = 'Dokonen';
$string['coursepacket'] = 'Balk kurzu';
$string['coursestruct'] = 'truktra kurzu';
$string['datadir'] = 'Chyba v systme sborov: Ned sa vytvori adresr s dajmi kurzu';
$string['details'] = 'Detaily priechodu SCO ';
$string['display'] = 'Zobraz';
$string['domxml'] = 'Extern kninica DOMXML';
$string['enablebrowse'] = 'Zapn nhad';
$string['entercourse'] = 'Vstpi do SCORM kurzu';
$string['errorlogs'] = 'Zznamy o chybch';
$string['exit'] = 'Opusti SCORM kurz';
$string['expcoll'] = 'Rozbali/Zabali';
$string['failed'] = 'Zlyhalo';
$string['firstaccess'] = 'Prv prstup';
$string['found'] = 'Manifest bol njden';
$string['frameheight'] = 'Tto hodnota nastav vchodziu hodnotu vky rmu SCO';
$string['framewidth'] = 'Tto hodnota nastav vchodziu hodnotu rky rmu SCO';
$string['gradeaverage'] = 'Priemern poet bodov';
$string['gradehighest'] = 'Najvy poet bodov';
$string['grademethod'] = 'Metda bodovania';
$string['gradescoes'] = 'Scoes situcia';
$string['gradesum'] = 'Celkov poet bodov';
$string['guestsno'] = 'Hosovskm pouvateom nie je povolen zobrazenie SCORM kurzov';
$string['height'] = 'Vka';
$string['incomplete'] = 'Nedokonen';
$string['lastaccess'] = 'Posledn prstup';
$string['missing_attribute'] = 'Chba atribt $a->attr v tagu $a->tag';
$string['missing_tag'] = 'Chba tag $a->tag';
$string['mode'] = 'Reim';
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMy';
$string['next'] = 'Pokraova';
$string['no_attributes'] = 'Tag $a->tag mus ma atribty';
$string['no_children'] = 'Tag $a->tag mus ma deti';
$string['noactivity'] = 'iadna sprva';
$string['nomanifest'] = 'Manifest nebol njden';
$string['noreports'] = 'iadna sprva na zobrazenie';
$string['normal'] = 'Normlny';
$string['not_corr_type'] = 'Neslad typov v tagu $a->tag';
$string['notattempted'] = 'Bez pokusov';
$string['organization'] = 'Organizcia';
$string['organizations'] = 'Organizcie';
$string['packagedir'] = 'Chyba v systme sborov: Ned sa vytvori adresr s balkom';
$string['passed'] = 'Preiel';
$string['php5'] = 'PHP 5 (DOMXML rodn kninica)';
$string['popup'] = 'Otvori sasn SCO v novom okne';
$string['position_error'] = 'Tag $a->tag neme by dieaom tagu $a->parent';
$string['prev'] = 'Predchdzajci';
$string['regular'] = 'Regulrny manifest';
$string['report'] = 'Sprva';
$string['review'] = 'Znovu prehliadnu';
$string['scoes'] = 'Scoes';
$string['score'] = 'Skre';
$string['syntax'] = 'Chyba v syntaxi';
$string['tag_error'] = 'Neznmy tag ($a->tag) s tmto obsahom: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag m prli mnoho atribtov';
$string['too_many_children'] = 'Tag $a->tag m prli mnoho det';
$string['totaltime'] = 'as';
$string['trackingloose'] = 'UPOZORNENIE: daje o priechode tmto SCORM balkom bud straten!';
$string['validateascorm'] = 'Overi SCORM balk';
$string['validation'] = 'Vsledok overovania';
$string['validationtype'] = 'Tto vlastnos nastavuje kninicu DOMXML, ktor bude pouit pri overovan manifestu SCORM. Ak neviete, o zvoli, nechajte tu vybrat odpove.';
$string['versionwarning'] = 'Verzia manifestu je staria ako 1.3, upozornenie na tagu $a->tag';
$string['viewallreports'] = 'Zobrazi sprvy pre $a pokusov';
$string['width'] = 'rka';

?>
